@@ -262,8 +262,8 @@ class AFNICommand(AFNICommandBase):
         Generate a filename based on the given parameters.
 
         The filename will take the form: cwd/basename<suffix><ext>.
-        If change_ext is True, it will use the extentions specified in
-        <instance>intputs.output_type.
+        If change_ext is True, it will use the extensions specified in
+        <instance>inputs.output_type.
 
         Parameters
         ----------
