@@ -24,7 +24,7 @@ from .base import (
 
 have_dcmstack = True
 try:
-    import dicom
+    import pydicom
     import dcmstack
     from dcmstack.dcmmeta import NiftiWrapper
 except ImportError:
@@ -34,7 +34,7 @@ except ImportError:
 def sanitize_path_comp(path_comp):
     result = []
     for char in path_comp:
-        if char not in string.letters + string.digits + "-_.":
+        if char not in string.ascii_letters + string.digits + "-_.":
             result.append("_")
         else:
             result.append(char)
@@ -55,7 +55,7 @@ class NiftiGeneratorBase(BaseInterface):
     embedded meta data."""
 
     def _get_out_path(self, meta, idx=None):
-        """Return the output path for the gernerated Nifti."""
+        """Return the output path for the generated Nifti."""
         if self.inputs.out_format:
             out_fmt = self.inputs.out_format
         else:
@@ -154,7 +154,7 @@ class DcmStack(NiftiGeneratorBase):
         stack = dcmstack.DicomStack(meta_filter=meta_filter)
         for src_path in src_paths:
             if not imghdr.what(src_path) == "gif":
-                src_dcm = dicom.read_file(src_path, force=self.inputs.force_read)
+                src_dcm = pydicom.dcmread(src_path, force=self.inputs.force_read)
                 stack.add_dcm(src_dcm)
         nii = stack.to_nifti(embed_meta=True)
         nw = NiftiWrapper(nii)
@@ -262,7 +262,7 @@ class LookupMeta(BaseInterface):
         return outputs
 
     def _run_interface(self, runtime):
-        # If the 'meta_keys' input is a list, covert it to a dict
+        # If the 'meta_keys' input is a list, convert it to a dict
         self._make_name_map()
         nw = NiftiWrapper.from_filename(self.inputs.in_file)
         self.result = {}
@@ -342,7 +342,7 @@ class MergeNiftiInputSpec(NiftiGeneratorBaseInputSpec):
     merge_dim = traits.Int(
         desc="Dimension to merge along. If not "
         "specified, the last singular or "
-        "non-existant dimension is used."
+        "non-existent dimension is used."
     )
 
 
