@@ -40,7 +40,7 @@ class IncrementInputSpec(nib.TraitedSpec):
 
 
 class IncrementOutputSpec(nib.TraitedSpec):
-    output1 = nib.traits.Int(desc="ouput")
+    output1 = nib.traits.Int(desc="output")
 
 
 class IncrementInterface(nib.SimpleInterface):
@@ -63,7 +63,7 @@ class SumInputSpec(nib.TraitedSpec):
 
 
 class SumOutputSpec(nib.TraitedSpec):
-    output1 = nib.traits.Int(desc="ouput")
+    output1 = nib.traits.Int(desc="output")
     operands = nib.traits.List(nib.traits.Int, desc="operands")
 
 
@@ -91,7 +91,7 @@ class SetInputSpec(nib.TraitedSpec):
 
 
 class SetOutputSpec(nib.TraitedSpec):
-    output1 = nib.traits.Int(desc="ouput")
+    output1 = nib.traits.Int(desc="output")
 
 
 class SetInterface(nib.BaseInterface):
